@@ -1,7 +1,8 @@
 package App::GitGitr::Cmd;
 our $AUTHORITY = 'cpan:GENEHACK';
-$App::GitGitr::Cmd::VERSION = '0.900';
-# ABSTRACT: GitGitr command support. See C<gitgitr> for full documentation.
+$App::GitGitr::Cmd::VERSION = '0.901';
+# ABSTRACT: GitGitr command support. See L<gitgitr> for full documentation.
+
 use parent 'App::Cmd::Simple';
 
 use strict;
@@ -74,7 +75,8 @@ sub execute {
 sub _build_version {
   my $content = get( 'http://git-scm.com/' );
   my $tree = HTML::TreeBuilder::XPath->new;
-  $tree->parse_content( $content );
+  $tree->parse_content( $content )
+    or croak "Failed to parse content from Git web page!";
   my $version = $tree->findvalue('/html/body//span[@class="version"]')
     or croak "Can't parse version from Git web page! $content";
   $version =~ s/^\s*//; $version =~ s/\s*$//;
@@ -157,11 +159,11 @@ __END__
 
 =head1 NAME
 
-App::GitGitr::Cmd - GitGitr command support. See C<gitgitr> for full documentation.
+App::GitGitr::Cmd - GitGitr command support. See L<gitgitr> for full documentation.
 
 =head1 VERSION
 
-version 0.900
+version 0.901
 
 =head1 AUTHOR
 
